/pol/ - Check the catalog before posting a new thread!Rep - Politically Incorrect - 4chan
Description: Check the catalog before posting a new thread! Reply to existing threads about a topic instead of st... - "/pol/ - Politically Incorrect" is 4chan's board for discussing and debating politics and current events.
Keywords: imageboard,politics,current events,debate,politically incorrect,Check,catalog,before,posting,thread,Reply,existing,threads,about,topic,instead

[a / b / c / d / e / f / g / gif / h / hr / k / m / o / p / r / s / t / u / v / vg / vm / vmg / vr / vrpg / vst / w / wg] [i / ic] [r9k / s4s / vip / qa] [cm / hm / lgbt / y] [3 / aco / adv / an / bant / biz / cgl / ck / co / diy / fa / fit / gd / hc / his / int / jp / lit / mlp / mu / n / news / out / po / pol / pw / qst / sci / soc / sp / tg / toy / trv / tv / vp / vt / wsg / wsr / x / xs] [Settings] [Search] [Mobile] [Home]
Board
▼ Settings Mobile Home
/pol/ - Politically Incorrect

Return Catalog Bottom Refresh

Thread closed.
You may not reply at this time.

[Return] [Catalog] [Bottom]

Anonymous ## Mod
05/31/20(Sun)15:07:39 No. 259848258
File: check catalog.jpg (44 KB, 452x343)
44 KB JPG
Anonymous ## Mod 05/31/20(Sun)15:07:39 No. 259848258

> Check the catalog before posting a new thread!

> Reply to existing threads about a topic instead of starting a new one. New users who do not abide by this principle will be temporarily blocked from creating threads. Mods will delete obvious duplicate threads and spam without notice. Don't bitch because your twitter screencap thread got deleted; there are probably other threads about it. Go look!

[Return] [Catalog] [Top]

Post a Reply
Return Catalog Top Refresh

Delete Post: [File Only] Style:
[Disable Mobile View / Use Desktop Site]
[Enable Mobile View / Use Mobile Site]
All trademarks and copyrights on this page are owned by their respective parties. Images uploaded are the responsibility of the Poster. Comments are owned by the Poster.